% GLL Depth prediction demo
% Catherine Higham, UoGlasgow January 2024

setup

%% get real data
clear all
HybridLidarDataReader240104


%% get yci2 and syi2 (standardised LiDar and smoothed LiDar)

load('Transfer1019/ImpRes/ImpRes.mat')

edges0 = 0.0075:0.0075:5;%note range between 0 and 5 metres
edges0 = edges0/10;
edges = [0,edges0]*10;

smoothwidth = 10;
for i = 1:size(fileList,1)
yc = imdb.lidar(:,2,i);
yc = yc-mean(yc);
yci2(:,i) = yc/max(yc);
y = filter(1,ImpRes,yc);
sy = fastsmooth(y,smoothwidth,3);
syi(:,i) = [sy(2:end);zeros(666-531,1)];
syi2(:,i) = sy/max(sy);
end


%% prepare data for depth prediction

jpglist = []; pnglist = []; grplist = [];
[jpglist,pnglist,grplist]=databasehelper1124(imdb.image,imdb.depth,edges,Nxy,jpglist,pnglist,grplist);
slct=1:size(jpglist,4);
myX = jpglist(:,:,2,slct);
myY = pnglist(:,:,2,slct);
myS = grplist(:,2,slct);
myS = reshape(myS,1,1,size(myS,1),size(myS,3));
myL = ones(size(jpglist,4),1);
% myXPlot = gpdl(myX(:,:,:,:),'SSCB');
% myYPlot = gpdl(myY(:,:,:,:),'SSCB');
% mySPlot = gpdl(myS(:,:,:,:),'SSCB');
% myLPlot = gpdl(myL(:),'B');

myXPlot = gpuArray(dlarray(myX(:,:,:,:),'SSCB'));
myYPlot = gpuArray(dlarray(myY(:,:,:,:),'SSCB'));
mySPlot = gpuArray(dlarray(myS(:,:,:,:),'SSCB'));
myLPlot = gpuArray(dlarray(myL(:),'B'));

mySPlot2=mySPlot;
mySPlot2(1,1,:,:)=max(syi,0);

%% load pretrained neural network and make GLL depth predction

load('gen2020_1115_40_v4.mat')

R = HyLiDAR_workreconst_1115v4(myXPlot,myYPlot/10,mySPlot2,myLPlot,Nxy,2*edges(2:end)/10,paramsGen,stGen);
R = extractdata(R);
R = 5*R;% adjustment for range 0 to 10 metres

%% evaluate performance scores

load('Results/rgbpred.mat')% predictions for RGBonly

for i = 1:size(jpglist,4)
xref = myYPlot(:,:,1,i)/10;
xref = extractdata(xref);
vref = R(:,:,1,i)/10;
pi(i) = psnr(single(gather(xref)),gather(vref));
ri(i) = 10*log10((xref(:)'*xref(:))/((xref(:)-vref(:))'*(xref(:)-vref(:))));
msei(i) = mse(xref,vref);
xref = gather(xref);
vref = predictions(:,:,i)/10;
vref = imresize(vref,[128,128]);
pni(i) = psnr(xref,vref);
rni(i) = 10*log10((xref(:)'*xref(:))/((xref(:)-vref(:))'*(xref(:)-vref(:))));
mseni(i) = mse(xref,vref);
end

edgesl = imdb.lidar(:,1,1)

R = gather(R);

summaryplot